@@ -1,13 +1,14 @@
 
-grow.shrink = function(x, cluster = NULL, whitelist, blacklist, test, alpha, B,
-  max.sx = ncol(x), complete, debug = FALSE) {
+grow.shrink = function(x, cluster = NULL, whitelist, blacklist, test, alpha,
+    extra.args = list(), max.sx = ncol(x), complete, debug = FALSE) {
 
   nodes = names(x)
 
   # 1. [Compute Markov Blankets]
   mb = smartSapply(cluster, as.list(nodes), gs.markov.blanket, data = x,
-         nodes = nodes, alpha = alpha, B = B, whitelist = whitelist,
-         blacklist = blacklist, test = test, max.sx = max.sx, debug = debug)
+         nodes = nodes, alpha = alpha, extra.args = extra.args,
+         whitelist = whitelist, blacklist = blacklist, test = test,
+         max.sx = max.sx, debug = debug)
   names(mb) = nodes
 
   # check markov blankets for consistency.
@@ -15,8 +16,8 @@ grow.shrink = function(x, cluster = NULL, whitelist, blacklist, test, alpha, B,
 
   # 2. [Compute Graph Structure]
   mb = smartSapply(cluster, as.list(nodes), neighbour, mb = mb, data = x,
-         alpha = alpha, B = B, whitelist = whitelist, blacklist = blacklist,
-         test = test, max.sx = max.sx, debug = debug)
+         alpha = alpha, extra.args = extra.args, whitelist = whitelist,
+         blacklist = blacklist, test = test, max.sx = max.sx, debug = debug)
   names(mb) = nodes
 
   # check neighbourhood sets for consistency.
@@ -26,8 +27,9 @@ grow.shrink = function(x, cluster = NULL, whitelist, blacklist, test, alpha, B,
 
 }#GROW.SHRINK
 
-gs.markov.blanket = function(x, data, nodes, alpha, B, whitelist, blacklist,
-  start = character(0), test, max.sx = ncol(x), debug = FALSE) {
+gs.markov.blanket = function(x, data, nodes, alpha, extra.args = list(),
+    whitelist, blacklist, start = character(0), test, max.sx = ncol(x),
+    debug = FALSE) {
 
   nodes = nodes[nodes != x]
   whitelisted = nodes[sapply(nodes,
@@ -77,7 +79,8 @@ gs.markov.blanket = function(x, data, nodes, alpha, B, whitelist, blacklist,
         cat("  * checking node", y, "for inclusion.\n")
 
 
-      a = indep.test(x, y, mb, data = data, test = test, B = B, alpha = alpha)
+      a = indep.test(x, y, mb, data = data, test = test,
+            extra.args = extra.args, alpha = alpha)
 
       if (a <= alpha) {
 
@@ -125,8 +128,8 @@ gs.markov.blanket = function(x, data, nodes, alpha, B, whitelist, blacklist,
       if (debug)
         cat("  * checking node", y, "for exclusion (shrinking phase).\n")
 
-      a = indep.test(x, y, mb[mb != y], data = data, test = test, B = B,
-            alpha = alpha)
+      a = indep.test(x, y, mb[mb != y], data = data, test = test,
+            extra.args = extra.args, alpha = alpha)
 
       if (a > alpha) {
 
